# Begin libfconf.sh

include common

function parse_config()
{

    FIREWALL_CONFIG_FILE=$(find_conf_file $1)
    if ! [ -f "$FIREWALL_CONFIG_FILE" ];then
	print_error "Couldn't find a correct config file."
	return 1
    fi

    if [ -f "$FIREWALL_CONFIG_FILE" -a -r "$FIREWALL_CONFIG_FILE" ];then
	
	include parse
	
	CONFIG_CONTENT="$(cat "$FIREWALL_CONFIG_FILE" | remove comment empty-line trim-lines )"
    else
	CONFIG_CONTENT=""
	print_error "Couldn't access '$FIREWALL_CONFIG_FILE' ..."
	return 1
	
    fi

    depends ifconfig
    Section "Reading '$YELLOW$FIREWALL_CONFIG_FILE$NORMAL'"

    #
    # local-if statements and computation of INTERNAL_IP and LOCALNET
    #

    
    Elt "looking for 'local-if' statement"
    LOCAL=$(echo "$CONFIG_CONTENT" | grep "^local-if " | cut -f 2 -d " ")
    if test -z  "$LOCAL"; then
	print_info "No local-if found"
	print_status failure
	Feed
	return 1
    fi
    if test "$(echo $(echo "$LOCAL" | wc -l))" != "1"; then
	lines=$(echo $(echo "$LOCAL" | wc -l))
    # TODO : we could accept more than one local-if.
	print_info "found $lines local-if ?!"
	print_status failure
	Feed
	return 1
    fi
    print_info "found statement"
    if !ifconfig "$LOCAL" >/dev/null 2>&1 ;then
	print_info "Not recognized"
	print_status failure
	print_error "Are you sure that '$LOCAL' appears in ifconfig ?"
	Feed
	return 1
    fi
    print_info "valid interface"
    INTERNAL_IP=$(ifip $LOCAL)
    if ! matches "$INTERNAL_IP" '/[0-9]\+\.[0-9]\+\.[0-9]\+\.[0-9]\+/' ;then
	print_info "ifip failed"
	print_status failure
	Feed
	return 1
    fi
    print_info "valid IP found"
    LOCALNET=$(ifnet $LOCAL)
    if ! matches "$LOCALNET" '/[0-9]\+\.[0-9]\+\.[0-9]\+\.[0-9]\+\/[0-9]\+\.[0-9]\+\.[0-9]\+\.[0-9]\+/'
	then
	print_info "ifnet failed"
	print_status failure
	Feed
	return 1
    fi
    print_info "valid if found"
    print_status success
    Feed


    #
    # local-if statements and computation of INTERNAL_IP and LOCALNET
    #

    Elt "looking for 'masq' statement"
    INTERNET=$(echo "$CONFIG_CONTENT" | grep "^masq " | cut -f 2 -d " ")
   

    if test -z "$INTERNET"; then
	print_info "No masq specified"
	print_status noop
	Feed
	masquerade="off"
    else
	print_info "masq found"
	
	if test "$(echo $(echo "$INTERNET" | wc -l))" != "1"; then
	    lines=$(echo $(echo "$LOCAL" | wc -l))
            # TODO : could we accept more than one masq ?.
	    print_info "found $lines masq ?!"
	    print_status failure
	    Feed
	    return 1
	fi
	print_info "found statement"

	if !ifconfig "$INTERNET" >/dev/null 2>&1 ;then
	    print_info "if not recognized"
	    if [ "$2" != "loose" ]; then
		print_status failure
		Feed
		return 1
	    else
		print_status warning
		Feed
	    fi
	else
	    print_info "valid interface"
	fi

	EXTERNAL_IP=$(ifip "$INTERNET")
	if ! matches "$EXTERNAL_IP" '/[0-9]\+\.[0-9]\+\.[0-9]\+\.[0-9]\+/' ;then
	    print_info "ifip failed"
	    if [ "$2" != "loose" ]; then
		print_status failure
		Feed
		return 1
	    else
		print_info "ifip - $EXTERNAL_IP"
		print_status warning
		Feed
	    fi
	else
	    print_info "valid if found"
	    print_status success
	fi
	Feed

	Elt "Temp lock file"
	IP_TMP_FILE=$(echo "$CONFIG_CONTENT" | grep "^masq " | cut -f 3 -d " ")
	if [ "$IP_TMP_FILE" == "" ];then
	    print_info "Not specified"
	    IP_TMP_FILE="/var/lock/firewall.lock"
	fi
	if [ ! -d "$(dirname "$IP_TMP_FILE")" ];then
	    print_info "not correct path"
	    print_status failure
	    Feed
	    return 1
	fi

	Elt "Temp lock file '$IP_TMP_FILE'"
	Feed
	    

	masquerade="on"
    fi
    
    for i in dnat drop accept; do
	Elt "getting ${YELLOW}$i${NORMAL} informations"
	export "${i}_CONFIG"="$(echo "$CONFIG_CONTENT" | grep "^$i " | cut -f 2 -d " " )"
	test "$(printenv "${i}_CONFIG")" != "" && lines=$(echo $(printenv "${i}_CONFIG" | wc -l))
	Feedback noop success "No directives found" "read $lines directives"
    done
    return 0

}


# End libfconf.sh
